@@ -75,6 +75,7 @@ UBX_CONFIG_DATABASE = {
     "CFG_BATCH_PIOENABLE": (0x10260014, L),
     "CFG_BATCH_PIOID": (0x20260019, U1),
     "CFG_BATCH_WARNTHRS": (0x30260016, U2),
+    "CFG_BDS_USE_GEO_PRN": (0x10340014, L),
     "CFG_BDS_USE_PRN_1_TO_5": (0x10340014, L),  # aka CFG_BDS_USE_GEO_PRN
     "CFG_GEOFENCE_CONFLVL": (0x20240011, E1),
     "CFG_GEOFENCE_FENCE1_LAT": (0x40240021, I4),
@@ -96,13 +97,13 @@ UBX_CONFIG_DATABASE = {
     "CFG_GEOFENCE_USE_FENCE3": (0x10240040, L),
     "CFG_GEOFENCE_USE_FENCE4": (0x10240050, L),
     "CFG_GEOFENCE_USE_PIO": (0x10240012, L),
-    "CFG_HW_ANT_CFG_OPENDET": (0x10A30031, L),
     "CFG_HW_ANT_CFG_OPENDET_POL": (0x10A30032, L),
-    "CFG_HW_ANT_CFG_PWRDOWN": (0x10A30033, L),
+    "CFG_HW_ANT_CFG_OPENDET": (0x10A30031, L),
     "CFG_HW_ANT_CFG_PWRDOWN_POL": (0x10A30034, L),
+    "CFG_HW_ANT_CFG_PWRDOWN": (0x10A30033, L),
     "CFG_HW_ANT_CFG_RECOVER": (0x10A30035, L),
-    "CFG_HW_ANT_CFG_SHORTDET": (0x10A3002F, L),
     "CFG_HW_ANT_CFG_SHORTDET_POL": (0x10A30030, L),
+    "CFG_HW_ANT_CFG_SHORTDET": (0x10A3002F, L),
     "CFG_HW_ANT_CFG_VOLTCTRL": (0x10A3002E, L),
     "CFG_HW_ANT_SUP_ENGINE": (0x20A30054, E1),
     "CFG_HW_ANT_SUP_OPEN_PIN": (0x20A30038, U1),
@@ -111,6 +112,8 @@ UBX_CONFIG_DATABASE = {
     "CFG_HW_ANT_SUP_SHORT_THR": (0x20A30055, U1),
     "CFG_HW_ANT_SUP_SWITCH_PIN": (0x20A30036, U1),
     "CFG_HW_RF_LNA_MODE": (0x20A30057, E1),
+    "CFG_HW_SENS_WOM_MODE": (0x20A30063, E1),
+    "CFG_HW_SENS_WOM_THLD": (0x20A30064, U1),
     "CFG_I2C_ADDRESS": (0x20510001, U1),
     "CFG_I2C_ENABLED": (0x10510003, L),
     "CFG_I2C_EXTENDEDTIMEOUT": (0x10510002, L),
@@ -136,8 +139,8 @@ UBX_CONFIG_DATABASE = {
     "CFG_ITFM_ANTSETTING": (0x20410010, E1),
     "CFG_ITFM_BBTHRESHOLD": (0x20410001, U1),
     "CFG_ITFM_CWTHRESHOLD": (0x20410002, U1),
-    "CFG_ITFM_ENABLE": (0x1041000D, L),
     "CFG_ITFM_ENABLE_AUX": (0x10410013, L),
+    "CFG_ITFM_ENABLE": (0x1041000D, L),
     "CFG_LOGFILTER_APPLY_ALL_FILTERS": (0x10DE0004, L),
     "CFG_LOGFILTER_MIN_INTERVAL": (0x30DE0005, U2),
     "CFG_LOGFILTER_ONCE_PER_WAKE_UP_ENA": (0x10DE0003, L),
@@ -392,6 +395,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_ESF_ALG_UART1": (0x20910110, U1),
     "CFG_MSGOUT_UBX_ESF_ALG_UART2": (0x20910111, U1),
     "CFG_MSGOUT_UBX_ESF_ALG_USB": (0x20910112, U1),
+    "CFG_MSGOUT_UBX_ESF_CAL_I2C": (0x209106AC, U1),
+    "CFG_MSGOUT_UBX_ESF_CAL_SPI": (0x209106B0, U1),
+    "CFG_MSGOUT_UBX_ESF_CAL_UART1": (0x209106AD, U1),
+    "CFG_MSGOUT_UBX_ESF_CAL_UART2": (0x209106AE, U1),
+    "CFG_MSGOUT_UBX_ESF_CAL_USB": (0x209106AF, U1),
     "CFG_MSGOUT_UBX_ESF_INS_I2C": (0x20910114, U1),
     "CFG_MSGOUT_UBX_ESF_INS_SPI": (0x20910118, U1),
     "CFG_MSGOUT_UBX_ESF_INS_UART1": (0x20910115, U1),
@@ -832,6 +840,18 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_RXM_IMES_UART1": (0x2091015B, U1),
     "CFG_MSGOUT_UBX_RXM_IMES_UART2": (0x2091015C, U1),
     "CFG_MSGOUT_UBX_RXM_IMES_USB": (0x2091015D, U1),
+    "CFG_MSGOUT_UBX_RXM_MEAS20_I2C": (0x20910643, U1),
+    "CFG_MSGOUT_UBX_RXM_MEAS20_SPI": (0x20910647, U1),
+    "CFG_MSGOUT_UBX_RXM_MEAS20_UART1": (0x20910644, U1),
+    "CFG_MSGOUT_UBX_RXM_MEAS50_I2C": (0x20910648, U1),
+    "CFG_MSGOUT_UBX_RXM_MEAS50_SPI": (0x2091064C, U1),
+    "CFG_MSGOUT_UBX_RXM_MEAS50_UART1": (0x20910649, U1),
+    "CFG_MSGOUT_UBX_RXM_MEASC12_I2C": (0x2091063E, U1),
+    "CFG_MSGOUT_UBX_RXM_MEASC12_SPI": (0x20910642, U1),
+    "CFG_MSGOUT_UBX_RXM_MEASC12_UART1": (0x2091063F, U1),
+    "CFG_MSGOUT_UBX_RXM_MEASD12_I2C": (0x20910639, U1),
+    "CFG_MSGOUT_UBX_RXM_MEASD12_SPI": (0x2091063D, U1),
+    "CFG_MSGOUT_UBX_RXM_MEASD12_UART1": (0x2091063A, U1),
     "CFG_MSGOUT_UBX_RXM_MEASX_I2C": (0x20910204, U1),
     "CFG_MSGOUT_UBX_RXM_MEASX_SPI": (0x20910208, U1),
     "CFG_MSGOUT_UBX_RXM_MEASX_UART1": (0x20910205, U1),
@@ -920,6 +940,24 @@ UBX_CONFIG_DATABASE = {
     "CFG_NAV2_OUT_ENABLED": (0x10170001, L),
     "CFG_NAV2_SBAS_USE_INTEGRITY": (0x10170002, L),
     "CFG_NAVHPG_DGNSSMODE": (0x20140011, E1),
+    "CFG_NAVMASK_EL_MASK_000_020": (0x50180001, X8),
+    "CFG_NAVMASK_EL_MASK_020_040": (0x50180002, X8),
+    "CFG_NAVMASK_EL_MASK_040_060": (0x50180003, X8),
+    "CFG_NAVMASK_EL_MASK_060_080": (0x50180004, X8),
+    "CFG_NAVMASK_EL_MASK_080_100": (0x50180005, X8),
+    "CFG_NAVMASK_EL_MASK_100_120": (0x50180006, X8),
+    "CFG_NAVMASK_EL_MASK_120_140": (0x50180007, X8),
+    "CFG_NAVMASK_EL_MASK_140_160": (0x50180008, X8),
+    "CFG_NAVMASK_EL_MASK_160_180": (0x50180009, X8),
+    "CFG_NAVMASK_EL_MASK_180_200": (0x5018000A, X8),
+    "CFG_NAVMASK_EL_MASK_200_220": (0x5018000B, X8),
+    "CFG_NAVMASK_EL_MASK_220_240": (0x5018000C, X8),
+    "CFG_NAVMASK_EL_MASK_240_260": (0x5018000D, X8),
+    "CFG_NAVMASK_EL_MASK_260_280": (0x5018000E, X8),
+    "CFG_NAVMASK_EL_MASK_280_300": (0x5018000F, X8),
+    "CFG_NAVMASK_EL_MASK_300_320": (0x50180010, X8),
+    "CFG_NAVMASK_EL_MASK_320_340": (0x50180011, X8),
+    "CFG_NAVMASK_EL_MASK_340_360": (0x50180012, X8),
     "CFG_NAVSPG_ACKAIDING": (0x10110025, L),
     "CFG_NAVSPG_CONSTR_ALT": (0x401100C1, I4),
     "CFG_NAVSPG_CONSTR_ALTVAR": (0x401100C2, U4),
@@ -961,6 +999,7 @@ UBX_CONFIG_DATABASE = {
     "CFG_NMEA_FILT_GAL": (0x10930013, L),
     "CFG_NMEA_FILT_GLO": (0x10930016, L),
     "CFG_NMEA_FILT_GPS": (0x10930011, L),
+    "CFG_NMEA_FILT_NAVIC": (0x10930018, L),
     "CFG_NMEA_FILT_QZSS": (0x10930015, L),
     "CFG_NMEA_FILT_SBAS": (0x10930012, L),
     "CFG_NMEA_GSVTALKERID": (0x20930032, E1),
@@ -1010,6 +1049,12 @@ UBX_CONFIG_DATABASE = {
     "CFG_PMP_USE_DESCRAMBLER": (0x10B10014, L),
     "CFG_PMP_USE_PRESCRAMBLING": (0x10B10019, L),
     "CFG_PMP_USE_SERVICE_ID": (0x10B10016, L),
+    "CFG_QZSS_L6_MSGA": (0x20370050, E1),
+    "CFG_QZSS_L6_MSGB": (0x20370060, E1),
+    "CFG_QZSS_L6_RSDECODER": (0x20370080, E1),
+    "CFG_QZSS_L6_SVIDA": (0x20370020, I1),
+    "CFG_QZSS_L6_SVIDB": (0x20370030, I1),
+    "CFG_QZSS_SLAS_MAX_BASELINE": (0x30370008, U2),
     "CFG_QZSS_USE_SLAS_DGNSS": (0x10370005, L),
     "CFG_QZSS_USE_SLAS_RAIM_UNCORR": (0x10370007, L),
     "CFG_QZSS_USE_SLAS_TESTMODE": (0x10370006, L),
@@ -1061,6 +1106,7 @@ UBX_CONFIG_DATABASE = {
     "CFG_SFODO_DIS_AUTODIRPINPOL": (0x10070005, L),
     "CFG_SFODO_DIS_AUTOSPEED": (0x10070006, L),
     "CFG_SFODO_DIS_AUTOSW": (0x10070011, L),
+    "CFG_SFODO_DIS_DIR_INFO": (0x1007001C, L),
     "CFG_SFODO_FACTOR": (0x40070007, U4),
     "CFG_SFODO_FREQUENCY": (0x2007000B, U1),
     "CFG_SFODO_LATENCY": (0x3007000A, U2),
@@ -1086,6 +1132,8 @@ UBX_CONFIG_DATABASE = {
     "CFG_SIGNAL_GPS_L5_ENA": (0x10310004, L),
     "CFG_SIGNAL_IMES_ENA": (0x10310023, L),
     "CFG_SIGNAL_IMES_L1_ENA": (0x10310011, L),
+    "CFG_SIGNAL_NAVIC_ENA": (0x10310026, L),
+    "CFG_SIGNAL_NAVIC_L5_ENA": (0x1031001D, L),
     "CFG_SIGNAL_QZSS_ENA": (0x10310024, L),
     "CFG_SIGNAL_QZSS_L1CA_ENA": (0x10310012, L),
     "CFG_SIGNAL_QZSS_L1S_ENA": (0x10310014, L),
