@@ -346,13 +346,16 @@ UBX_MSGIDS = {
     b"\x29\x35": "NAV2-SAT",
     b"\x29\x32": "NAV2-SBAS",
     b"\x29\x43": "NAV2-SIG",
+    b"\x29\x42": "NAV2-SLAS",
     b"\x29\x03": "NAV2-STATUS",
+    b"\x29\x3b": "NAV2-SVIN",
     b"\x29\x24": "NAV2-TIMEBDS",
     b"\x29\x25": "NAV2-TIMEGAL",
     b"\x29\x23": "NAV2-TIMEGLO",
     b"\x29\x20": "NAV2-TIMEGPS",
     b"\x29\x26": "NAV2-TIMELS",
     b"\x29\x63": "NAV2-TIMENAVIC",
+    b"\x29\x27": "NAV2-TIMEQZSS",
     b"\x29\x21": "NAV2-TIMEUTC",
     b"\x29\x11": "NAV2-VELECEF",
     b"\x29\x12": "NAV2-VELNED",
