@@ -3550,13 +3550,16 @@ _UBX_PAYLOADS_GET_NAV2 = {
     "NAV2-SAT": UBX_PAYLOADS_GET["NAV-SAT"],
     "NAV2-SBAS": UBX_PAYLOADS_GET["NAV-SBAS"],
     "NAV2-SIG": UBX_PAYLOADS_GET["NAV-SIG"],
+    "NAV2-SLAS": UBX_PAYLOADS_GET["NAV-SLAS"],
     "NAV2-STATUS": UBX_PAYLOADS_GET["NAV-STATUS"],
+    "NAV2-SVIN": UBX_PAYLOADS_GET["NAV-SVIN"],
     "NAV2-TIMEBDS": UBX_PAYLOADS_GET["NAV-TIMEBDS"],
     "NAV2-TIMEGAL": UBX_PAYLOADS_GET["NAV-TIMEGAL"],
     "NAV2-TIMEGLO": UBX_PAYLOADS_GET["NAV-TIMEGLO"],
     "NAV2-TIMEGPS": UBX_PAYLOADS_GET["NAV-TIMEGPS"],
     "NAV2-TIMELS": UBX_PAYLOADS_GET["NAV-TIMELS"],
     "NAV2-TIMENAVIC": UBX_PAYLOADS_GET["NAV-TIMENAVIC"],
+    "NAV2-TIMEQZSS": UBX_PAYLOADS_GET["NAV-TIMEQZSS"],
     "NAV2-TIMEUTC": UBX_PAYLOADS_GET["NAV-TIMEUTC"],
     "NAV2-VELECEF": UBX_PAYLOADS_GET["NAV-VELECEF"],
     "NAV2-VELNED": UBX_PAYLOADS_GET["NAV-VELNED"],
